PlotWidget — pyqtgraph 0.11.0rc0 documentation

# PlotWidget

class `pyqtgraph.` `PlotWidget`(parent=None, background='default', **kargs)
  `__init__`(parent=None, background='default', **kargs)

    When initializing PlotWidget, parent and background are passed to `GraphicsWidget.__init__()` and all others are passed to `PlotItem.__init__()`.

  `close`(self) → bool
  `getPlotItem`()

    Return the PlotItem contained within.

  `sigTransformChanged` = <PySide2.QtCore.Signal object>

    `GraphicsView` widget with a single `PlotItem` inside.

    The following methods are wrapped directly from PlotItem: `addItem`, `removeItem`, `clear`, `setXRange`, `setYRange`, `setRange`, `autoRange`, `setXLink`, `setYLink`, `viewRect`, `setMouseEnabled`, `enableAutoRange`, `disableAutoRange`, `setAspectLocked`, `setLimits`, `register`, `unregister`

    For all other methods, use `getPlotItem`.